namespace demo{
namespace sublibA{

enum class ConsoleForegroundColor {
    Green = 32,
    Yellow = 33,
    Blue = 34,
    Magenta = 35,
    None_ = -1
};

enum ConsoleBackgroundColor {
    Green = 42,
    Yellow = 43,
    Blue = 44,
    Magenta = 45
};

}
}
